import React, { useState } from 'react';
import classNames from 'classnames';
import { useDashboard } from '../../context';
import styles from './index.less';

// 导航项数据类型
interface NavItem {
  key: string;
  label: string;
  icon: string;
  hasChildren?: boolean;
  children?: NavSubItem[];
}

interface NavSubItem {
  key: string;
  label: string;
}

const NavigationBar: React.FC = () => {
  const { backToHome } = useDashboard();
  const [activeKey, setActiveKey] = useState<string | null>(null);
  
  // 导航项数据
  const navItems: NavItem[] = [
    {
      key: 'home',
      label: '首页',
      icon: 'map-navigate-logo-1.png',
    },
    {
      key: 'cityStatus',
      label: '城市实况',
      icon: 'map-navigate-logo-2.png',
      hasChildren: true,
      children: [
        { key: 'cityStatus1', label: '智慧照明' },
        { key: 'cityStatus2', label: '智慧井盖' },
        { key: 'cityStatus3', label: '共享单车' },
        { key: 'cityStatus4', label: '餐饮油烟' },
        { key: 'cityStatus5', label: '智慧管廊' },
        { key: 'cityStatus6', label: '智慧公厕' },
        { key: 'cityStatus7', label: '数字巡查' },
        { key: 'cityStatus8', label: '网络舆情' },
        { key: 'cityStatus9', label: '百姓投诉' },
      ]
    },
    {
      key: 'videoMonitor',
      label: '视频监控',
      icon: 'map-navigate-logo-3.png',
    },
    {
      key: 'industryStatus',
      label: '行业概况',
      icon: 'map-navigate-logo-4.png',
    },
    {
      key: 'overview',
      label: '整体概况',
      icon: 'map-navigate-logo-5.png',
    },
    {
      key: 'specialService',
      label: '专项服务',
      icon: 'map-navigate-logo-6.png',
    },
  ];

  // 处理导航项点击
  const handleNavItemClick = (item: NavItem) => {
    if (item.key === 'home') {
      // 首页按钮点击时返回首页
      backToHome();
      setActiveKey(null);
    } else if (item.hasChildren) {
      // 有子项的导航项，切换展开/折叠状态
      setActiveKey(activeKey === item.key ? null : item.key);
    } else {
      // 普通导航项，设置为激活状态
      setActiveKey(item.key);
    }
  };

  // 处理子导航项点击
  const handleSubItemClick = (parentKey: string, subKey: string) => {
    // 根据子项key执行相应操作
    console.log(`Clicked sub item: ${parentKey} - ${subKey}`);
  };

  return (
    <div className={styles.navigationBar}>
      <div className={styles.navItems}>
        {navItems.map(item => (
          <div key={item.key} className={styles.navItemContainer}>
            <div
              className={classNames(styles.navItem, {
                [styles.navItemActive]: activeKey === item.key
              })}
              onClick={() => handleNavItemClick(item)}
            >
              <img 
                src={require(`@/assets/images/V-2504/${item.icon}`)} 
                className={styles.navIcon}
                alt=""
              />
              <span className={styles.navLabel}>{item.label}</span>
            </div>
            
            {/* 子导航项 */}
            {activeKey === item.key && item.hasChildren && item.children && (
              <div className={styles.subNavItems}>
                {item.children.map(subItem => (
                  <div
                    key={subItem.key}
                    className={styles.subNavItem}
                    onClick={() => handleSubItemClick(item.key, subItem.key)}
                  >
                    {subItem.label}
                  </div>
                ))}
              </div>
            )}
          </div>
        ))}
      </div>
    </div>
  );
};

export default NavigationBar; 